summaryrefslogtreecommitdiff
path: root/src/third_party/wiredtiger/src/include/btmem.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/third_party/wiredtiger/src/include/btmem.h')
-rw-r--r--src/third_party/wiredtiger/src/include/btmem.h25
1 files changed, 12 insertions, 13 deletions
diff --git a/src/third_party/wiredtiger/src/include/btmem.h b/src/third_party/wiredtiger/src/include/btmem.h
index 79297af1743..24562280ac1 100644
--- a/src/third_party/wiredtiger/src/include/btmem.h
+++ b/src/third_party/wiredtiger/src/include/btmem.h
@@ -1111,14 +1111,13 @@ struct __wt_update {
volatile uint8_t prepare_state; /* prepare state */
/* AUTOMATIC FLAG VALUE GENERATION START */
-#define WT_UPDATE_BEHIND_MIXED_MODE 0x01u /* Update that older than a mixed mode update. */
-#define WT_UPDATE_CLEARED_HS 0x02u /* Update that cleared the history store. */
-#define WT_UPDATE_DS 0x04u /* Update has been written to the data store. */
-#define WT_UPDATE_HS 0x08u /* Update has been written to history store. */
-#define WT_UPDATE_PREPARE_RESTORED_FROM_DS 0x10u /* Prepared update restored from data store. */
-#define WT_UPDATE_RESTORED_FAST_TRUNCATE 0x20u /* Fast truncate instantiation */
-#define WT_UPDATE_RESTORED_FROM_DS 0x40u /* Update restored from data store. */
-#define WT_UPDATE_RESTORED_FROM_HS 0x80u /* Update restored from history store. */
+#define WT_UPDATE_DS 0x01u /* Update has been written to the data store. */
+#define WT_UPDATE_FIXED_HS 0x02u /* Update that fixed the history store. */
+#define WT_UPDATE_HS 0x04u /* Update has been written to history store. */
+#define WT_UPDATE_PREPARE_RESTORED_FROM_DS 0x08u /* Prepared update restored from data store. */
+#define WT_UPDATE_RESTORED_FAST_TRUNCATE 0x10u /* Fast truncate instantiation */
+#define WT_UPDATE_RESTORED_FROM_DS 0x20u /* Update restored from data store. */
+#define WT_UPDATE_RESTORED_FROM_HS 0x40u /* Update restored from history store. */
/* AUTOMATIC FLAG VALUE GENERATION STOP */
uint8_t flags;
@@ -1187,17 +1186,17 @@ struct __wt_update_value {
* avoid heap allocation, add a few additional slots to that array.
*/
#define WT_MAX_MODIFY_UPDATE 10
-#define WT_MODIFY_VECTOR_STACK_SIZE (WT_MAX_MODIFY_UPDATE + 10)
+#define WT_UPDATE_VECTOR_STACK_SIZE 20
/*
* WT_MODIFY_VECTOR --
* A resizable array for storing modify updates. The allocation strategy is similar to that of
* llvm::SmallVector<T> where we keep space on the stack for the regular case but fall back to
* dynamic allocation as needed.
*/
-struct __wt_modify_vector {
+struct __wt_update_vector {
WT_SESSION_IMPL *session;
- WT_UPDATE *list[WT_MODIFY_VECTOR_STACK_SIZE];
+ WT_UPDATE *list[WT_UPDATE_VECTOR_STACK_SIZE];
WT_UPDATE **listp;
size_t allocated_bytes;
size_t size;
@@ -1187,17 +1186,17 @@ struct __wt_update_value {
/*
- * WT_MODIFY_VECTOR --
- * A resizable array for storing modify updates. The allocation strategy is similar to that of
+ * WT_UPDATE_VECTOR --
+ * A resizable array for storing updates. The allocation strategy is similar to that of
* llvm::SmallVector<T> where we keep space on the stack for the regular case but fall back to
* dynamic allocation as needed.